@@ -24,7 +24,7 @@ class OWtc_slit(XoppyWidget):
     id = "orange.widgets.data_tc_slit"
     description = "Undulator Tuning Curves (Flux on a slit)"
     icon = "icons/xoppy_xtc.png"
-    priority = 8
+    priority = 6
     category = ""
     keywords = ["xoppy", "tc_slit"]
 
@@ -41,14 +41,17 @@ class OWtc_slit(XoppyWidget):
     DISTANCE = Setting(26.0)
     GAPH = Setting(0.00258)
     GAPV = Setting(0.00195)
-    KMIN = Setting(0.01)
-    KMAX = Setting(2.56)
+    KMIN = Setting(0.001)
+    KMAX = Setting(3.0)
     KPOINTS = Setting(10)
-    HMAX = Setting(1)
+    HARMONICS = Setting("1") # sequence of harmonics, separated by ","
     METHOD = Setting(2)
 
     inputs = WidgetDecorator.syned_input_data()
 
+    def __init__(self):
+        super().__init__(show_script_tab=True)
+
     def build_gui(self):
 
         box = oasysgui.widgetBox(self.controlArea, self.name + " Input Parameters", orientation="vertical", width=self.CONTROL_AREA_WIDTH-5)
@@ -193,9 +196,10 @@ class OWtc_slit(XoppyWidget):
         #widget index 15
         idx += 1
         box1 = gui.widgetBox(box)
-        oasysgui.lineEdit(box1, self, "HMAX",
+        # TODO: add validator
+        oasysgui.lineEdit(box1, self, "HARMONICS",
                      label=self.unitLabels()[idx], addSpace=False,
-                    valueType=int, validator=QIntValidator(), orientation="horizontal", labelWidth=250)
+                    valueType=str, orientation="horizontal", labelWidth=250)
         self.show_at(self.unitFlags()[idx], box1)
 
         #widget index 16
@@ -216,7 +220,7 @@ class OWtc_slit(XoppyWidget):
                  "Electron Beam Divergence H [rad]", "Electron Beam Divergence V [rad]",
                  "Period ID [m]", "Number of periods",
                  "Distance to slit [m]", "Slit gap H [m]", "Slit gap V [m]",
-                 "K Min", "K Max", "Number of K Points", "higher harmonic", "calculation code"]
+                 "K Min", "K Max", "Number of K Points", "harmonics (e.g: 1,3)", "calculation code"]
 
     def unitFlags(self):
          return ["True", "True", "self.USEEMITTANCES == 1 and self.METHOD != 1", "True",
@@ -247,7 +251,7 @@ class OWtc_slit(XoppyWidget):
         self.KMAX = congruence.checkStrictlyPositiveNumber(self.KMAX, "K Max")
         congruence.checkLessThan(self.KMIN, self.KMAX, "K Min", "K Max")
         self.KPOINTS = congruence.checkStrictlyPositiveNumber(self.KPOINTS, "Number of K Points")
-        self.HMAX = congruence.checkStrictlyPositiveNumber(self.HMAX, "Higher harmonic")
+        # self.HARMONICS = congruence.checkStrictlyPositiveNumber(self.HARMONIX, "Higher harmonic")
 
     def do_xoppy_calculation(self):
         return self.xoppy_calc_tc_slit()
@@ -260,7 +264,8 @@ class OWtc_slit(XoppyWidget):
 
         harmonics_data = []
 
-        for ih,harmonic_number in enumerate(harmonics):
+        for ih in range(len(harmonics)):
+            harmonic_number = int(harmonics[ih])
             harmonics_data.append([harmonic_number,None])
 
             data = numpy.zeros((K_scan.size, 5))
@@ -313,7 +318,6 @@ class OWtc_slit(XoppyWidget):
             if not calculated_data is None:
                 self.view_type_combo.setEnabled(False)
 
-
                 xoppy_data_harmonics = calculated_data.get_content("xoppy_data_harmonics")
 
                 titles = self.getTitles()
@@ -350,10 +354,7 @@ class OWtc_slit(XoppyWidget):
                                                          "Click on curve to highlight it",
                                                          xlabel=xtitles[index], ylabel=ytitles[index],
                                                          symbol='', color='white')
-                        # self.plot_canvas[index].setActiveCurve("Click on curve to highlight it")
-                        # self.plot_canvas[index].showLegends()
 
-                        self.tabs.setCurrentIndex(index)
                     except Exception as e:
                         self.view_type_combo.setEnabled(True)
 
@@ -361,6 +362,7 @@ class OWtc_slit(XoppyWidget):
 
 
                 self.view_type_combo.setEnabled(True)
+                self.tabs.setCurrentIndex(0)
             else:
                 raise Exception("Empty Data")
 
@@ -386,25 +388,22 @@ class OWtc_slit(XoppyWidget):
         return "TC_SLIT"
 
     def getTitles(self):
-        return ["Flux on slit","Spectral power on slit","Ky","Total power on slit"]
+        return ["Flux on slit","Spectral power on slit","Kv","Total power on slit"]
 
     def getXTitles(self):
         return ["Energy (eV)","Energy (eV)","Energy (eV)","Kv"]
 
     def getYTitles(self):
-        return ["Flux (photons/s/0.1%bw)","Spectral power (W/eV)","Ky","Total power (W)"]
+        return ["Flux (photons/s/0.1%bw)","Spectral power (W/eV)","Kv","Total power (W)"]
 
     def getVariablesToPlot(self):
-        return [(0, 1), (0, 2), (0, 3), (2, 3)]
+        return [(0, 1), (0, 2), (0, 3), (3, 4)]
 
     def getLogPlot(self):
         return[(False, False), (False, False), (False, False), (False, False)]
 
     def xoppy_calc_tc_slit(self):
 
-
-        print("Inside xoppy_calc_undulator_spectrum. ")
-
         bl = OrderedDict()
         bl['ElectronBeamDivergenceH'] = self.ELECTRONBEAMDIVERGENCEH
         bl['ElectronBeamDivergenceV'] = self.ELECTRONBEAMDIVERGENCEV
@@ -431,21 +430,96 @@ class OWtc_slit(XoppyWidget):
         if self.METHOD == 2:
             code = "srw"
 
-        harmonics = []
-        for i in range(self.HMAX+1):
-            if i % 2 != 0: harmonics.append(i)
+        harmonics = str(self.HARMONICS).split(",") #[]
+        # for i in range(self.HARMONICS+1):
+        #     if i % 2 != 0: harmonics.append(i)
 
         K_scan,harmonics,power_array, energy_values_at_flux_peak,flux_values = srundplug.tuning_curves_on_slit(bl,
-                    Kmin=self.KMIN,Kmax=self.KMAX,Kpoints=self.KPOINTS,harmonics=harmonics,
-                    zero_emittance=zero_emittance,do_plot_peaks=False,code=code)
+                    Kmin=self.KMIN,
+                    Kmax=self.KMAX,
+                    Kpoints=self.KPOINTS,
+                    harmonics=harmonics,
+                    zero_emittance=zero_emittance,
+                    do_plot_peaks=False,
+                    code=code)
 
         if zero_emittance:
             print("\nNo emittance calculation")
 
         print("Done")
 
+        # write python script in standard output
+        dict_parameters = {
+            'ElectronBeamDivergenceH' : self.ELECTRONBEAMDIVERGENCEH,
+            'ElectronBeamDivergenceV' : self.ELECTRONBEAMDIVERGENCEV,
+            'ElectronBeamSizeH'       : self.ELECTRONBEAMSIZEH,
+            'ElectronBeamSizeV'       : self.ELECTRONBEAMSIZEV,
+            'ElectronCurrent'         : self.ELECTRONCURRENT,
+            'ElectronEnergy'          : self.ELECTRONENERGY,
+            'ElectronEnergySpread'    : self.ELECTRONENERGYSPREAD,
+            'NPeriods'                : self.NPERIODS,
+            'PeriodID'                : self.PERIODID,
+            'distance'                : self.DISTANCE,
+            'gapH'                    : self.GAPH,
+            'gapV'                    : self.GAPV,
+            'HARMONICS'                    : self.HARMONICS,
+            'Kmin'                    : self.KMIN,
+            'Kmax'                    : self.KMAX,
+            'Kpoints'                 : self.KPOINTS,
+            'harmonics'               : harmonics,
+            'zero_emittance'          : zero_emittance,
+            'do_plot_peaks'           : False,
+            'code'                    : code,
+            }
+
+        self.xoppy_script.set_code(self.script_template().format_map(dict_parameters))
+
+
         return K_scan,harmonics,power_array,energy_values_at_flux_peak,flux_values
 
+    def script_template(self):
+        return """
+#
+# script to make the calculations (created by XOPPY:tc_slit)
+#
+from collections import OrderedDict
+from orangecontrib.xoppy.util import srundplug
+
+
+bl = OrderedDict()
+bl['ElectronBeamDivergenceH'] = {ElectronBeamDivergenceH}
+bl['ElectronBeamDivergenceV'] = {ElectronBeamDivergenceV}
+bl['ElectronBeamSizeH']       = {ElectronBeamSizeH}
+bl['ElectronBeamSizeV']       = {ElectronBeamSizeV}
+bl['ElectronCurrent']         = {ElectronCurrent}
+bl['ElectronEnergy']          = {ElectronEnergy}
+bl['ElectronEnergySpread']    = {ElectronEnergySpread}
+bl['NPeriods']                = {NPeriods}
+bl['PeriodID']                = {PeriodID}
+bl['distance']                = {distance}
+bl['gapH']                    = {gapH}
+bl['gapV']                    = {gapV}
+
+harmonics = "{HARMONICS}".split(",")
+
+K_scan,harmonics,power_array, energy_values_at_flux_peak,flux_values = srundplug.tuning_curves_on_slit(bl,
+    Kmin={Kmin},
+    Kmax={Kmax},
+    Kpoints={Kpoints},
+    harmonics=harmonics,
+    zero_emittance={zero_emittance},
+    do_plot_peaks={do_plot_peaks},
+    code="{code}")
+      
+from srxraylib.plot.gol import plot
+plot(energy_values_at_flux_peak,flux_values,xtitle="Photon energy [eV]",ytitle="Flux on slit [photons/s/0.1%bw]")
+              
+#
+# end script
+#
+"""
+
+
     def receive_syned_data(self, data):
 
         if isinstance(data, synedb.Beamline):
@@ -500,9 +574,6 @@ class OWtc_slit(XoppyWidget):
                 self.id_KMAX.setEnabled(False)
 
 
-
-
-
 if __name__ == "__main__":
     app = QApplication(sys.argv)
     w = OWtc_slit()
