@@ -1,5 +1,6 @@
 import sys,os
 import numpy
+import platform
 from PyQt5.QtWidgets import QApplication
 from PyQt5.QtGui import QIntValidator, QDoubleValidator
 
@@ -215,7 +216,7 @@ class OWxtc(XoppyWidget):
                  'Period length (cm)','Number of periods',
                  'E1 minimum energy (eV)','E1 maximum energy (eV)',
                  'Number of energy-points','Minimum harmonic number','Maximum harmonic number','Harmonic step size',
-                 'Mode','Method','Intrinsic NEKS']
+                 'Mode','Method','Neks OR % Helicity']
 
 
     def unitFlags(self):
@@ -243,7 +244,7 @@ class OWxtc(XoppyWidget):
         self.HARMONIC_TO = congruence.checkStrictlyPositiveNumber(self.HARMONIC_TO, "Maximum harmonic number")
         congruence.checkLessThan(self.HARMONIC_FROM, self.HARMONIC_TO, "Minimum harmonic number", "Maximum harmonic number")
         self.HARMONIC_STEP = congruence.checkStrictlyPositiveNumber(self.HARMONIC_STEP, "Harmonic step size")
-        self.NEKS  = congruence.checkPositiveNumber(self.NEKS , "Intrinsic NEKS")
+        self.NEKS  = congruence.checkPositiveNumber(self.NEKS , "Neks OR % Helicity")
 
     def do_xoppy_calculation(self):
         return self.xoppy_calc_xtc()
@@ -363,7 +364,13 @@ class OWxtc(XoppyWidget):
             f.write("%d %d %d %d %s\n"%(self.HELICAL,self.METHOD,1,self.NEKS,"Helical Method Print_K Neks"))
             f.write("foreground\n")
 
-        command = "'" + os.path.join(locations.home_bin(), 'tc') + "'"
+
+        if platform.system() == "Windows":
+            command = os.path.join(locations.home_bin(),'tc.exe')
+        else:
+            command = "'" + os.path.join(locations.home_bin(), 'tc') + "'"
+
+
         print("Running command '%s' in directory: %s "%(command, locations.home_bin_run()))
         print("\n--------------------------------------------------------\n")
         os.system(command)
